@@ -6,9 +6,7 @@ def test_cesu8():
     cls2 = bad_codecs.search_function("cesu-8").__class__
     assert cls1 == cls2
 
-    test_bytes = (
-        b"\xed\xa6\x9d\xed\xbd\xb7 is an unassigned character, and \xc0\x80 is null"
-    )
+    test_bytes = b"\xed\xa6\x9d\xed\xbd\xb7 is an unassigned character, and \xc0\x80 is null"
     test_text = "\U00077777 is an unassigned character, and \x00 is null"
     assert test_bytes.decode("cesu8") == test_text
 
